# -*- coding: utf-8 -*-

import json
import numpy as np
import pandas as pd
from ._common import (BaseReader, Path, datadir, TEAMNAME_REPLACEMENTS)


class FiveThirtyEight(BaseReader):
    """ Provides pandas.DataFrames from the fivethirtyeight.com project
    "2016-17 Club Soccer Predictions"

    Data will be downloaded as necessary and cached locally in ./data

    Original project and background info:
    https://projects.fivethirtyeight.com/soccer-predictions/
    https://fivethirtyeight.com/features/how-our-club-soccer-projections-work/

    Source JSON:
    https://projects.fivethirtyeight.com/soccer-predictions/data.json

    Parameters
    ----------
    leagues : string or iterable of league-ids to include, None for all
    """

    def __init__(self, leagues=None):
        super(FiveThirtyEight, self).__init__(leagues=leagues)
        self._data = {}

        url = 'https://projects.fivethirtyeight.com/soccer-predictions/data.json'
        filepath = Path(datadir(), 'FiveThirtyEight_1617.json')
        if not filepath.exists():
            self._download_and_save(url, filepath)

        with filepath.open(encoding='utf-8') as data_file:
            for k, v in json.load(data_file).items():
                self._data[k] = v

    def read_leagues(self):
        """Returns a Dataframe of selected leagues from the datasource"""
        df = (
            pd.DataFrame.from_dict(self._data['leagues'])
            .rename(columns={'slug': 'league', 'id': 'league_id'})
            .pipe(self._translate_league)
            .set_index('league')
            .loc[self._selected_leagues.keys()]
            .sort_index()
        )
        return df

    def read_games(self):
        """Returns a Dataframe of all games for the selected leagues"""

        col_rename = {
            'adj_score1': 'adj_score_home',
            'adj_score2': 'adj_score_away',
            'chances1': 'chances_home',
            'chances2': 'chances_away',
            'datetime': 'date',
            'moves1': 'moves_home',
            'moves2': 'moves_away',
            'prob1': 'prob_home',
            'prob2': 'prob_away',
            'probtie': 'prob_tie',
            'score1': 'score_home',
            'score2': 'score_away',
            'team1': 'home_team',
            'team1_code': 'home_code',
            'team1_id': 'home_id',
            'team1_sdr_id': 'home_sdr_id',
            'team2': 'away_team',
            'team2_code': 'away_code',
            'team2_id': 'away_id',
            'team2_sdr_id': 'away_sdr_id'
        }

        keys = [(v, v + '_matches') for v in self._selected_leagues.values()]

        df = (
            pd.concat(
                [(pd.DataFrame.from_dict(self._data[mkey])
                  .assign(league=lkey)
                  ) for lkey, mkey in keys]
            )
            .rename(columns=col_rename)
            .assign(date=lambda x: pd.to_datetime(x['date']))
            .replace({'home_team': TEAMNAME_REPLACEMENTS,
                      'away_team': TEAMNAME_REPLACEMENTS})
            .drop('id', axis=1)
            .assign(season='1617')
            .replace('None', np.nan)
            .pipe(self._translate_league)
        )

        df['game_id'] = df.apply(self._make_game_id, axis=1)
        df.set_index(['league', 'season', 'game_id'], inplace=True)
        df.sort_index(inplace=True)
        return df

    def read_forecasts(self):
        """Returns a Dataframe of forecasted results for all games for the selected leagues"""
        keys = [(v, v + '_forecast') for v in self._selected_leagues.values()]

        df_list = []
        for lkey, fkey in keys:
            forecast_by_date = self._data[fkey]['forecasts']
            df_list += [
                (pd.DataFrame.from_dict(f['teams'])
                    .assign(league=lkey)
                    .assign(
                    last_updated=lambda x: pd.to_datetime(f['last_updated']))
                ) for f in forecast_by_date]

        df = (pd.concat(df_list)
              .rename(columns={'name': 'team'})
              .replace({'team': TEAMNAME_REPLACEMENTS})
              .replace('None', np.nan)
              .pipe(self._translate_league)
              .set_index(['league', 'last_updated', 'team'])
              .sort_index()
              )
        return df

    def read_clinches(self):
        """Returns a Dataframe of clinches for the selected leagues"""
        keys = [(v, v + '_clinches') for v in self._selected_leagues.values()]

        df = (pd.concat([(pd.DataFrame.from_dict(self._data[ckey])
                          .assign(league=lkey)
                          ) for lkey, ckey in keys]
                        )
              .assign(date=lambda x: pd.to_datetime(x['dt']))
              .drop('dt', axis=1)
              .pipe(self._translate_league)
              .set_index(['league', 'date'])
              .sort_index()
              )
        return df



# -*- coding: utf-8 -*-

import numpy as np
import pprint
import requests
import sys

if sys.version_info >= (3, 4):
    from pathlib import Path
else:
    from pathlib2 import Path

TEAMNAME_REPLACEMENTS = {
    'Akhisar': u'Akhisar Belediyespor',
    'Alaves': u'Alavés',
    'Alkmaar': u'AZ Alkmaar',
    'Ath Bilbao': u'Athletic Bilbao',
    'Ath Madrid': u'Atletico Madrid',
    'Atletico': u'Atletico Madrid',
    'Aue': u'Erzgebirge Aue',
    'Augsburg': u'FC Augsburg',
    'Bayern': u'Bayern München',
    'Bayern Munich': u'Bayern München',
    'Betis': u'Real Betis',
    'Beveren': u'Waasland-Beveren',
    'Bilbao': u'Athletic Bilbao',
    'Borussia Monchengladbach': u'Borussia Mönchengladbach',
    'Bourg-Peronnas': u'Bourg Peronnas',
    'Bournemouth': u'AFC Bournemouth',
    'Braga': u'Sp Braga',
    'Brugge': u'Club Brugge',
    'Bueyueksehir': u'Büyüksehir',
    'Buyuksehyr': u'Büyüksehir',
    'Celta': u'Celta de Vigo',
    'Celta Vigo': u'Celta de Vigo',
    'Chievo': u'Chievo Verona',
    'Darmstadt': u'SV Darmstadt 98',
    'Den Haag': u'ADO Den Haag',
    'Depor': u'Deportivo La Coruña',
    'Dijon': u'Dijon FCO',
    'Dortmund': u'Borussia Dortmund',
    'Duesseldorf': u'Fortuna Düsseldorf',
    'Ein Frankfurt': u'Eintracht Frankfurt',
    'Entella': u'Virtus Entella',
    'Espanol': u'Espanyol',
    'FC Cologne': u'FC Köln',
    'FC Koln': u'FC Augsburg',
    'Forest': u'Nottingham Forest',
    'Fortuna Dusseldorf': u'Fortuna Düsseldorf',
    'Frankfurt': u'Eintracht Frankfurt',
    'Freiburg': u'SC Freiburg',
    'Fuerth': u'Greuther Furth',
    'Gijon': u'Sporting Gijón',
    'Gladbach': u'Borussia Mönchengladbach',
    'Groningen': u'FC Groningen',
    'Hamburg': u'Hamburg SV',
    'Hertha': u'Hertha Berlin',
    'Hoffenheim': u'TSG Hoffenheim',
    'Hull': u'Hull City',
    'Ingolstadt': u'FC Ingolstadt 04',
    'Inter': u'Internazionale',
    'Karabuekspor': u'Karabükspor',
    'Karabukspor': u'Karabükspor',
    'Kayseri': u'Kayserispor',
    'Koeln': u'FC Köln',
    'La Coruna': u'Deportivo La Coruña',
    'Lautern': u'Kaiserslautern',
    'Leicester': u'Leicester City',
    'Leverkusen': u'Bayer Leverkusen',
    "M'gladbach": u'Borussia Mönchengladbach',
    'Malaga': u'Málaga',
    'Man City': u'Leicester City',
    'Man United': u'Manchester United',
    'Milan': u'AC Milan',
    'Monaco': u'AS Monaco',
    'Muenchen 60': u'München 1860',
    'Munich 1860': u'München 1860',
    'Nancy': u'AS Nancy Lorraine',
    'Nijmegen': u'NEC Nijmegen',
    "Nott'm Forest": u'Nottingham Forest',
    'Nuernberg': u'Nürnberg',
    'Nurnberg': u'Nürnberg',
    'PSV Eindhoven': u'PSV',
    'Paris SG': u'Paris Saint-Germain',
    'Pescara': u'US Pescara',
    'Rennes': u'Stade Rennes',
    'Roda': u'Roda JC',
    'Roma': u'AS Roma',
    'Saint-Etienne': u'St Etienne',
    'Schalke': u'Schalke 04',
    'Sevilla': u'Sevilla FC',
    'Sociedad': u'Real Sociedad',
    'Sp Gijon': u'Sporting Gijón',
    'Stoke': u'Stoke City',
    'Swansea': u'Swansea City',
    'Tottenham': u'Tottenham Hotspur',
    'Twente': u'FC Twente',
    'Utrecht': u'FC Utrecht',
    'Vallecano': u'Rayo Vallecano',
    'Waregem': u'Zulte Waregem',
    'Werder': u'Werder Bremen',
    'West Brom': u'West Bromwich Albion',
    'West Ham': u'West Ham United',
    'Wolfsburg': u'VfL Wolfsburg',
    'Wuerzburg': u'Würzburger Kickers',
    'Wurzburger Kickers': u'Würzburger Kickers',
    'Zwolle': u'PEC Zwolle'}

# TEAMNAME_REPLACEMENTS = {'Den Haag': 'ADO Den Haag'}

LEAGUE_DICT = {
    'ENG-Premier League': {
        'ClubElo': 'ENG_1',  # Used to id on clubelo.co)m
        'MatchHistory': 'E0',  # Code used on football-data.co.uk
        'MH_from_season': '9394',  # Availability on football-data.co.uk
        'FiveThirtyEight': 'premier-league',  # Slug used on fivethirtyeight.com
    },
    'ENG-Championship': {
        'ClubElo': 'ENG_2',
        'MatchHistory': 'E1',
        'MH_from_season': '9394'
    },  # Division 1 before 2004
    'ENG-League 1': {
        'MatchHistory': 'E2',
        'MH_from_season': '9394'
    },  # Division 2 before 2004
    'ENG-League 2': {
        'MatchHistory': 'E3',
        'MH_from_season': '9394'
    },  # Division 3 before 2004
    'ENG-Conference': {
        'MatchHistory': 'EC',
        'MH_from_season': '0506'
    },
    'SCO-Premiership': {
        'ClubElo': 'SCO_1',
        'MatchHistory': 'SC0',
        'MH_from_season': '9495'
    },  # Previously Scottish Premier League
    'SCO-Division 1': {
        'MatchHistory': 'SC1',
        'MH_from_season': '9495'
    },  # Division 1 before 2004
    'SCO-Division 2': {
        'MatchHistory': 'SC2',
        'MH_from_season': '9798'
    },  # Division 2 before 2004
    'SCO-Division 3': {
        'MatchHistory': 'SC3',
        'MH_from_season': '9798'
    },  # Division 3 before 2004
    'GER-Bundesliga': {
        'ClubElo': 'GER_1',
        'MatchHistory': 'D1',
        'MH_from_season': '9394',
        'FiveThirtyEight': 'bundesliga',
    },
    'GER-Bundesliga 2': {
        'ClubElo': 'GER_2',
        'MatchHistory': 'D2',
        'MH_from_season': '9394'
    },
    'ESP-La Liga': {
        'ClubElo': 'ESP_1',
        'MatchHistory': 'SP1',
        'MH_from_season': '9394',
        'FiveThirtyEight': 'la-liga',
    },
    'ESP-La Liga 2': {
        'ClubElo': 'ESP_2',
        'MatchHistory': 'SP2',
        'MH_from_season': '9697'
    },
    'ITA-Serie A': {
        'ClubElo': 'ITA_1',
        'MatchHistory': 'I1',
        'MH_from_season': '9394',
        'FiveThirtyEight': 'serie-a',
    },
    'ITA-Serie B': {
        'ClubElo': 'ITA_2',
        'MatchHistory': 'I2',
        'MH_from_season': '9798',
    },
    'FRA-Ligue 1': {
        'ClubElo': 'FRA_1',
        'MatchHistory': 'F1',
        'MH_from_season': '9394',
        'FiveThirtyEight': 'ligue-1',
    },
    'FRA-Ligue 2': {
        'ClubElo': 'FRA_2',
        'MatchHistory': 'F2',
        'MH_from_season': '9697',
    },
    'NED-Eredivisie': {
        'ClubElo': 'NED_1',
        'MatchHistory': 'N1',
        'MH_from_season': '9394',
    },
    'BEL-Jupiler League': {
        'ClubElo': 'BEL_1',
        'MatchHistory': 'B1',
        'MH_from_season': '9596',
    },
    'POR-Liga 1': {
        'ClubElo': 'POR_1',
        'MatchHistory': 'P1',
        'MH_from_season': '9495',
    },
    'TUR-Ligi 1': {
        'ClubElo': 'TUR_1',
        'MatchHistory': 'T1',
        'MH_from_season': '9495',
    },
    'GRE-Ethniki Katigoria': {
        'ClubElo': 'GRE_1',
        'MatchHistory': 'G1',
        'MH_from_season': '9495',
    },
    'USA-MLS': {
        'FiveThirtyEight': 'mls',
    },
    'USA-NWSL': {
        'FiveThirtyEight': 'nwsl',
    },
    'MEX-Liga MX': {
        'FiveThirtyEight': 'liga-mx',
    },
    'Champions League': {
        'FiveThirtyEight': 'champions-league',
    },
}


def datadir(directory='data'):
    """Return pathlib.Path to <cwd>/data
    Creates this directory if it doesn't exist
    """
    path = Path(directory)
    if not path.exists():
        path.mkdir()
    return path


class BaseReader(object):
    """Base class for datareaders"""

    def __init__(self, leagues=None):
        self._selected_leagues = leagues

    @staticmethod
    def _make_game_id(row):
        """Returns a game-id based on date, home and away team"""
        game_id = u'{} {}-{}'.format(
            row['date'].strftime("%Y-%m-%d"),
            row['home_team'],
            row['away_team']
        )
        return game_id

    @classmethod
    def _download_and_save(cls, url, filepath):
        """Downloads file at url to filepath
        Overwrites if filepath exists
        """
        r = requests.get(url)
        r.raise_for_status()
        with filepath.open(mode='wb') as f:
            f.write(r.content)

    @classmethod
    def available_leagues(cls):
        """Returns a list of league-ids available for this source"""
        return sorted(list(cls._all_leagues().keys()))

    @classmethod
    def _all_leagues(cls):
        """Returns a dict mapping all canonical league-ids to source league-ids"""
        if not hasattr(cls, '_all_leagues_dict'):
            cls._all_leagues_dict = {
                k: v[cls.__name__]
                for k, v in LEAGUE_DICT.items()
                if cls.__name__ in v
            }
        return cls._all_leagues_dict

    @classmethod
    def _translate_league(cls, df, col='league'):
        """Dataframe: source league id to canonical id"""
        flip = {v: k for k, v in cls._all_leagues().items()}
        mask = ~df[col].isin(flip)
        df.loc[mask, col] = np.nan
        df[col] = df[col].replace(flip)
        return df

    @property
    def _selected_leagues(self):
        """A dict mapping selected canonical league-ids to source league-ids"""
        if not hasattr(self, '_leagues_dict'):
            self._leagues_dict = self._all_leagues()
        return self._leagues_dict

    @_selected_leagues.setter
    def _selected_leagues(self, ids=None):
        if ids is None:
            self._leagues_dict = self._all_leagues()
        else:
            if len(ids) == 0:
                raise ValueError("Empty iterable not allowed for 'leagues'")
            if isinstance(ids, str):
                ids = [ids]
            tmp_league_dict = {}
            for i in ids:
                if i not in self._all_leagues():
                    raise ValueError(
                        "Invalid league '{}'.\nValid leagues are:\n{}"
                        .format(i, pprint.pformat(self.available_leagues())))
                tmp_league_dict[i] = self._all_leagues()[i]
            self._leagues_dict = tmp_league_dict



"""
A collection of tools to read and process football data
from various sources.
"""


__all__ = ['FiveThirtyEight', 'ClubElo', 'MatchHistory']

from .FiveThirtyEight import FiveThirtyEight
from .ClubElo import ClubElo
from .MatchHistory import MatchHistory



# -*- coding: utf-8 -*-

from datetime import date
import itertools
import pandas as pd
import re
import warnings
from ._common import (BaseReader, Path, datadir, TEAMNAME_REPLACEMENTS)


class MatchHistory(BaseReader):
    """Provides pandas.DataFrames from CSV files available at
    http://www.football-data.co.uk/data.php

    Column names are explained here: http://www.football-data.co.uk/notes.txt

    Data will be downloaded as necessary and cached locally in ./data

    Parameters
    ----------
    leagues : string or iterable of league-ids to include, None for all
    seasons : string, int or list of seasons. Examples:
              '16-17'; 2016; '2016-17'; [14, 15, 16]
    """

    def __init__(self, leagues, seasons):
        super(MatchHistory, self).__init__(leagues=leagues)
        self.seasons = seasons

    def read_games(self):
        """Returns game history for the selected leagues and
        seasons in a pandas.DataFrame.
        """

        urlmask = 'http://www.football-data.co.uk/mmz4281/{}/{}.csv'
        filemask = 'MatchHistory_{}_{}.csv'
        col_rename = {
            'Div': 'league',
            'Date': 'date',
            'HomeTeam': 'home_team',
            'AwayTeam': 'away_team',
        }

        df_list = []
        current_season_ends = str(date.today().year)[-2:]
        for lkey, skey in itertools.product(self._selected_leagues.values(),
                                      self.seasons):
            filepath = Path(datadir(), filemask.format(lkey, skey))
            url = urlmask.format(skey, lkey)
            current_season = skey[-2:] >= current_season_ends
            if current_season or (not filepath.exists()):
                self._download_and_save(url, filepath)

            df_list.append(
                pd.read_csv(str(filepath),
                            parse_dates=['Date'],
                            infer_datetime_format=True,
                            dayfirst=True,
                            encoding='UTF-8',
                            )
                    .assign(season=skey)
            )

        df = (
            pd.concat(df_list)
            .rename(columns=col_rename)
            .pipe(self._translate_league)
            .replace({'home_team': TEAMNAME_REPLACEMENTS,
                      'away_team': TEAMNAME_REPLACEMENTS})
            .dropna(subset=['home_team', 'away_team'])
        )

        df['game_id'] = df.apply(self._make_game_id, axis=1)
        df.set_index(['league', 'season', 'game_id'], inplace=True)
        df.sort_index(inplace=True)
        return df

    @staticmethod
    def _season_code(season):
        """Takes a string or int and tries to convert it to a
        season code like '1718'
        """
        season = str(season)
        pat1 = re.compile(r'^[0-9]{4}$')  # 1994 | 9495
        pat2 = re.compile(r'^[0-9]{2}$')  # 94
        pat3 = re.compile(r'^[0-9]{4}-[0-9]{4}$')  # 1994-1995
        pat4 = re.compile(r'^[0-9]{4}-[0-9]{2}$')  # 1994-95
        pat5 = re.compile(r'^[0-9]{2}-[0-9]{2}$')  # 94-95

        if re.match(pat1, season):
            if int(season[2:]) == int(season[:2]) + 1:
                if season == '1920' or season == '2021':
                    msg = ('Season id "{}" is ambiguous: interpreting as "{}-{}"'
                           .format(season, season[:2], season[-2:]))
                    warnings.warn(msg)
                return season  # 9495
            elif season[2:] == '99':
                return ''.join([season[2:], '00'])  # 1999
            else:
                return ''.join([season[-2:], '{:02d}'.format(int(season[-2:]) + 1)])  # 1994
        elif re.match(pat2, season):
            if season == '99':
                return ''.join([season, '00'])  # 99
            else:
                return ''.join([season, '{:02d}'.format(int(season) + 1)])  # 94
        elif re.match(pat3, season):
            return ''.join([season[2:4], season[-2:]])  # 1994-1995
        elif re.match(pat4, season):
            return ''.join([season[2:4], season[-2:]])  # 1994-95
        elif re.match(pat5, season):
            return ''.join([season[:2], season[-2:]])  # 94-95
        else:
            return season

    @classmethod
    def _download_and_save(cls, url, filepath):
        """Downloads file at url to filepath
        Overwrites if filepath exists
        """
        super(MatchHistory, cls)._download_and_save(url, filepath)

        # Strip trailing commas from Excel-generated csv, fix encoding
        filepath_tmp = Path('tmpfile')
        with filepath_tmp.open(mode='w', encoding='UTF-8') as tmpfile:
            with filepath.open(mode='r', encoding='ISO-8859-1') as file:
                for line in file.readlines():
                    tmpfile.write(line.rstrip(',\n'))
                    tmpfile.write(u'\n')
        filepath_tmp.rename(filepath)

    @property
    def seasons(self):
        return self._season_ids

    @seasons.setter
    def seasons(self, seasons):
        if isinstance(seasons, str) or isinstance(seasons, int):
            seasons = [seasons]
        self._season_ids = [self._season_code(s) for s in seasons]



# -*- coding: utf-8 -*-

from datetime import datetime, timedelta
import pandas as pd
from ._common import (BaseReader, Path, datadir,
                      TEAMNAME_REPLACEMENTS)


class ClubElo(BaseReader):
    """Provides pandas.DataFrames from CSV API at http://api.clubelo.com

    Data will be downloaded as necessary and cached locally in ./data

    Since the source does not provide league names, this class will
    not filter by league. League names will be inserted from the other
    sources where available. Leagues that are only covered by clubelo.com
    will have NaN values.
    """

    def __init__(self):
        super(ClubElo, self).__init__()

    def read_by_date(self, date=None):
        """Returns ELO scores for all teams at specified date in
        a pandas.DataFrame.

        If no date is specified, get today's scores

        Parameters
        ----------
        date : datetime object or string like 'YYYY-MM-DD'
        """

        if not date:
            date = datetime.today()
        elif isinstance(date, str):
            date = datetime.strptime(date, "%Y-%m-%d")
        else:
            pass  # Assume datetime object

        datestring = date.strftime("%Y-%m-%d")
        filepath = Path(datadir(), 'ClubElo_{}.csv'.format(datestring))
        url = 'http://api.clubelo.com/{}'.format(datestring)

        if not filepath.exists():
            self._download_and_save(url, filepath)

        df = (pd.read_csv(str(filepath),
                          parse_dates=['From', 'To'],
                          infer_datetime_format=True,
                          dayfirst=False
                          )
              .rename(columns={'Club': 'team'})
              .replace({'team': TEAMNAME_REPLACEMENTS})
              .assign(league=lambda x: x['Country'] + '_' + x['Level'].astype(str))
              .pipe(self._translate_league)
              .reset_index(drop=True)
              .set_index('team')
              )
        return df

    def read_team_history(self, team, max_age=1):
        """Downloads full ELO history for one team

        Returns pandas.DataFrame

        Parameters
        ----------
        team : string club name
        max_age : max. age of local file before re-download
                integer for age in days, or timedelta object
        """

        if isinstance(max_age, int):
            _max_age = timedelta(days=max_age)
        elif isinstance(max_age, timedelta):
            _max_age = max_age
        else:
            raise TypeError('max_age must be of type int or datetime.timedelta')

        teams_to_check = [k.replace(' ', '') for k, v in TEAMNAME_REPLACEMENTS.items() if v == team]
        teams_to_check.append(team.replace(' ', ''))

        for _team in teams_to_check:
            filepath = Path(datadir(), 'clubelo_{}.csv'.format(_team))
            url = 'http://api.clubelo.com/{}'.format(_team)

            if not filepath.exists():
                self._download_and_save(url, filepath)
            else:
                last_modified = datetime.fromtimestamp(filepath.stat().st_mtime)
                now = datetime.now()
                if (now - last_modified) > _max_age:
                    self._download_and_save(url, filepath)

            df = (pd.read_csv(str(filepath),
                              parse_dates=['From', 'To'],
                              infer_datetime_format=True,
                              dayfirst=False)
                  .rename(columns={'Club': 'team'})
                  .set_index('From')
                  .sort_index()
                  )
            if len(df) > 0:
                df.replace(
                    {'team': TEAMNAME_REPLACEMENTS},
                    inplace=True
                )
                return df

        # clubelo.com returns a CSV with just a header for nonexistent club
        raise ValueError('No data found for team {}'.format(team))



import setuptools

setuptools.setup(
    name='footballdata',
    version='0.3.0',
    url='https://github.com/skagr/footballdata',
    license='MIT',

    author='Skag Rijsdijk',
    author_email='skag.rijsdijk@gmail.com',

    description='A collection of wrappers over football (soccer) data '
                'from various websites / APIs. You get: Pandas dataframes '
                 'with sensible, matching column names and identifiers '
                 'across datasets. Data is downloaded when needed and cached '
                 'locally. Example Jupyter Notebooks are in the Github repo.',

    long_description=open('README.rst').read(),

    packages=['footballdata'],

    install_requires=[
        'numpy',
        'pandas',
        'requests',
        'pathlib2;python_version<"3.4"'
    ],

    classifiers=[
        # 'Development Status :: 1 - Planning',
        # 'Development Status :: 2 - Pre-Alpha',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',
        # 'Development Status :: 6 - Mature',
        # 'Development Status :: 7 - Inactive',
        'License :: OSI Approved :: MIT License',
        'Topic :: Software Development :: Libraries',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],

    keywords=['football', 'soccer', 'metrics', 'sports', 'statistics'],
)
